// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2003 Liam Girdwood  

#ifndef _CASTOR_COMET_HH
#define _CASTOR_COMET_HH

#include "near_object.hh"

namespace Castor
{
	
class Comet : public NearObject
{
	public:
		Comet();
		Comet(Glib::ustring& name, Glib::ustring& id, struct ln_ell_orbit& orbit,
					double g, double k);
		Comet(Glib::ustring& name, Glib::ustring& id, struct ln_par_orbit& orbit,
					double g, double k);
		~Comet();
	
		/*! \fn void get_posn(double& ra, double& dec);
		* \brief Get object Right Ascension and Declination
		*/
		void get_equ_posn(double JD, double& ra, double& dec);
		
		/*! \fn void get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn);
		* \brief Get object horizontal position
		*/
		void get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn);
		
		/*! \fn void get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time);
		* \brief Get object rise, transit and set time.
		*/
		void get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time);
		
		/*! \fn double get_mag(double JD) = 0;
		* \brief Get object Magnitude
		*/
		double get_mag(double JD);
				
		/*! \fn void get_id(std::string& id);
		* \brief Get object identification number.
		*/
		void get_id(std::string& id);
		
		/*! \fn void get_name(std::string& name);
		* \brief Get object name.
		*/
		void get_name(std::string& name);
		
		/*! \fn virtual void get_info (std::list<Glib::ustring>& value);
		* \brief Get object information
		*/
		void get_info (std::list<Glib::ustring>& value);
		
		/*! \fn virtual double get_earth_dist (double JD);
		* \brief Calculate the distance between object and the Earth.
		*/ 
		virtual double get_earth_dist (double JD);
			
		/*! \fn virtual double get_sun_dist (double JD);
		* \brief Calculate the distance between object and the Sun.
		*/ 
		virtual double get_sun_dist (double JD);
		
		/*! \fn void render(double x, double y, double mag_max, Gnome::Canvas::Group& group);
		* \brief Render object
		*/
		void render(double x, double y, double mag_max, Gnome::Canvas::Group& group, bool bright, double ppd = 0);
	
		void set_render_jd (double JD);
		
	private:
		struct ln_ell_orbit m_eorbit;
		struct ln_par_orbit m_porbit;
		bool m_is_parabolic;
		double m_g;
		double m_k;
		Glib::ustring m_name;
};

}

#endif
