// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2003 Liam Girdwood  

#ifndef _CASTOR_NEBULA_HH
#define _CASTOR_NEBULA_HH

#include "deep_object.hh"

namespace Castor
{
	
class Nebula : public DeepObject
{
	public:
		Nebula();
		~Nebula();
	
		/*! \fn void get_posn(double& ra, double& dec);
		* \brief Get object Right Ascension and Declination
		*/
		void get_equ_posn(double& ra, double& dec, double JD = 0);

		/*! \fn void get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn);
		* \brief Get object horizontal position
		*/
		void get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn);
		
		/*! \fn void get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time);
		* \brief Get object rise, transit and set time.
		*/
		void get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time);
		
		/*! \fn double get_ra() = 0;
		* \brief Get object Right Ascension
		*/
		void get_posn(double& ra, double& dec);
		
		/*! \fn double get_mag() = 0;
		* \brief Get object Magnitude
		*/
		double get_mag();
				
		/*! \fn void get_id(std::string& id);
		* \brief Get object identification number.
		*/
		void get_id(std::string& id);
		
		/*! \fn void get_name(std::string& name);
		* \brief Get object name.
		*/
		void get_name(std::string& name);
		
		/*! \fn virtual void get_info (std::list<Glib::ustring>& value);
		* \brief Get object information
		*/
		void get_info (std::list<Glib::ustring>& value);
		
		/*! \fn void render(double x, double y, double mag_max, Gnome::Canvas::Group& group);
		* \brief Render object
		*/
		void render(double x, double y, double mag_max, Gnome::Canvas::Group& group, bool bright);
	
		double get_disk (double JD);
};

}

#endif
