// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2003 Liam Girdwood  

#ifndef _CASTOR_PLANET_HH
#define _CASTOR_PLANET_HH

#include "near_object.hh"
#include <libgnomecanvasmm/ellipse.h>

namespace Castor
{
	
class Planet : public NearObject
{
	public:
	
		/*! \fn virtual void get_posn(double& ra, double& dec) = 0;
		* \brief Get object Right Ascension and Declination
		*/
		virtual void get_equ_posn(double JD, double& ra, double& dec) = 0;
		
		/*! \fn virtual void get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn) = 0;
		* \brief Get object horizontal position
		*/
		virtual void get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn) = 0;
		
		/*! \fn virtual void get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time) = 0;
		* \brief Get object rise, transit and set time.
		*/
		virtual void get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time) = 0;
		
		/*! \fn virtual double get_mag (double JD) = 0;
		* \brief Calculate the visible magnitude of object
		*/ 
		virtual double get_mag(double JD) = 0;
				
		/*! \fn virtual void get_id(std::string& id) = 0;
		* \brief Get object identification number.
		*/
		virtual void get_id(std::string& id) = 0;
		
		/*! \fn virtual void get_name(std::string& name) = 0;
		* \brief Get object name.
		*/
		virtual void get_name(std::string& name) = 0;
		
		/*! \fn virtual void get_info (std::list<Glib::ustring>& value) = 0;
		* \brief Get object information
		*/
		virtual void get_info (std::list<Glib::ustring>& value) = 0;
		
		/*! \fn virtual void render(double x, double y, double mag_max, Gnome::Canvas::Group& group) = 0;
		* \brief Render object
		*/
		virtual void render(double x, double y, double mag_max, Gnome::Canvas::Group& group, bool bright, double ppd = 0) = 0;
	
		/*! \fn virtual double get_equ_sdiam (double JD) = 0;
		* \brief Calcaluate the equatorial semidiameter of object in arc seconds.
		*/
		virtual double get_equ_sdiam (double JD) = 0;
		
		/*! \fn virtual double get_pol_sdiam (double JD) = 0
		* \brief Calcaluate the polar semidiameter of Jupiter in arc seconds.
		*/
		virtual double get_pol_sdiam (double JD) = 0;
		
		/*! \fn virtual void get_helio_coords (double JD, struct ln_helio_posn * position) = 0;
		* \brief Calculate object's heliocentric coordinates
		*/ 
		virtual void get_helio_coords (double JD, struct ln_helio_posn * position) = 0;
		
		/*! \fn virtual double get_earth_dist (double JD) = 0;
		* \brief Calculate the distance between object and the Earth.
		*/ 
		virtual double get_earth_dist (double JD) = 0;
			
		/*! \fn virtual double get_sun_dist (double JD) = 0;
		* \brief Calculate the distance between object and the Sun.
		*/ 
		virtual double get_sun_dist (double JD) = 0;
		
		/*! \fn virtual double get_disk (double JD) = 0;
		* \brief Calculate the illuminated fraction of object's disk
		*/ 
		virtual double get_disk (double JD) = 0;
		
		/*! \fn virtual double get_phase (double JD) = 0;
		* \brief Calculate the phase angle of object.
		*/ 
		virtual double get_phase (double JD) = 0;
		
		/*! \fn virtual void get_rect_helio (double JD, struct ln_rect_posn * position) = 0;
		* \brief Calculate object rectangular heliocentric coordinates.
		*/
		virtual void get_rect_helio (double JD, struct ln_rect_posn * position) = 0;

		/*! \fn virtual set_render_jd (double JD) = 0;
		* \brief Set the cached JD for rendering
		*/
		virtual void set_render_jd (double JD) = 0;
	
	private:
};

}

#endif
