// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2003 Liam Girdwood  

#include "sol.hh"
#include <libnova.h>

namespace Castor
{

Sol::Sol()
{
}

Sol::~Sol()
{
}

double Sol::get_sdiam (double JD)
{
	return get_solar_sdiam(JD);
}
	
/*! \fn void Sol::get_equ_posn (double JD, ln_equ_posn* posn)
* \brief Get object equatorial position.
*/
void Sol::get_equ_posn (double JD, double& ra, double& dec)
{
	struct ln_equ_posn posn;
	get_equ_solar_coords(JD, &posn);
	ra = posn.ra;
	dec = posn.dec;
}

/*! \fn void Sol::get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn)
* \brief Get object horizontal position
*/
void Sol::get_hrz_posn (double JD, ln_lnlat_posn* observer, ln_hrz_posn* posn)
{
	struct ln_equ_posn equ_posn;
		
	get_equ_solar_coords(JD, &equ_posn);
	get_hrz_from_equ (&equ_posn, observer, JD, posn);
}

/*! \fn void Sol::get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time)
* \brief Get object rise, transit and set time.
*/
void Sol::get_rst_time (double JD, ln_lnlat_posn* observer, ln_rst_time* time)
{
	get_solar_rst(JD, observer, time);
}

/*! \fn double Sol::get_mag()
* \brief Get object Magnitude
*/
double Sol::get_mag()
{
	return -26.8; // needs improvement
}
		
/*! \fn void Sol::get_id(std::string& id)
* \brief Get object identification number.
*/
void Sol::get_id(std::string& id)
{
	id = "Sun";
}	

/*! \fn void Sol::get_name(std::string& name)
* \brief Get object name.
*/
void Sol::get_name(std::string& name)
{
	name = "Sun";
}

/*! \fn void Sol::get_info (std::list<Glib::ustring>& value)
* \brief Get object information
*/
void Sol::get_info (std::list<Glib::ustring>& value)
{
}

/*! \fn void Sol::render(double x, double y, double mag_max, Gnome::Canvas::Group& group)
* \brief Render object
*/
void Sol::render(double x, double y, double mag_max, Gnome::Canvas::Group& group, bool bright, double ppd)
{
	// draw object on canvas
	double size = (mag_max + 1) - get_neptune_magnitude(m_render_JD);
	double sdiam = (get_sdiam(m_render_JD) / 240.0) * ppd;
	if (size < sdiam)
		size = sdiam;
	double shadow = 1.1 * size;
	Gnome::Canvas::Ellipse *ellipse_back, *ellipse;
	
	if (!bright) {
		// draw the background shadow object
		ellipse_back = Gtk::manage (new Gnome::Canvas::Ellipse(group, x - shadow, y - shadow, x + shadow, y + shadow));
		*ellipse_back << Gnome::Canvas::Properties::fill_color("black");
		ellipse_back->show();
	}
	
	// draw real colour object
	ellipse = Gtk::manage (new Gnome::Canvas::Ellipse(group, x - size, y - size, x + size, y + size));
	ellipse->set_data (Glib::Quark("object"),(gpointer)this);
	*ellipse << Gnome::Canvas::Properties::fill_color("yellow");
	ellipse->show();
}

}
