// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright Liam Girdwood 2003

#ifndef _SPLASH_HH
#define _SPLASH_HH

#include <gtkmm/box.h>
#include <gtkmm/label.h>
#include <gtkmm/progressbar.h>
#include <gtkmm/image.h>
#include <glibmm/thread.h>
#include <gtkmm/main.h>
#include <gtkmm/window.h>

namespace GUI
{

/*! \class Splash
* \brief Nova Splash Screen
*
* Creates thae splash screen and loads the default catalogs. 
*/
class Splash : public Gtk::Window
{
	public:
		
		/*! \fn Splash()
		* \brief Constructor
		*/
		Splash();
	
		/*! \fn ~Splash()
		* \brief Destructor
		*/
		~Splash();
	
		/*! \fn void import_default (void);
		* \brief Import default catalogs
		*/
		void import_default (void);
	
		/*! \fn void init_import(void);
		* \brief Initialise importer
		*/
		void init_import(void);
	
		/*! \fn bool import_status(void);
		* \brief Was the default catalog laoded OK ?
		*/
		bool import_status(void);
	
	private:
	
		/*! \fn void progress_increment();
		* \brief Increment progress
		*/
		void progress_increment();
	
		Glib::Dispatcher nova_signal;	/*!< progess signal */
		Gtk::VBox* vbox;				
		Gtk::Label* splash_label;		/*!< splash label */
		Gtk::ProgressBar* progress;		/*!< Progress bar */
		Gtk::Image* logo;				/*!< Nova Logo */
		Gtk::Label* cat_label;			/*!< Catalog label */
		Gtk::Label* status_label;		/*!< Status label */
		Gtk::HBox* hbox;
		bool m_import_status;
};

};

#endif
