// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright Liam Girdwood 2003

#ifndef _NOVA_PAGE_HH
#define _NOVA_PAGE_HH

#include <gtkmm/box.h>
#include <glibmm/ustring.h>

/*! \namespace Polaris
* \brief Nova Multiple Document Interface
*/
namespace Polaris
{

/*! \class NovaPage
* \brief Abstract base class of all nova documents
*/	
class NovaPage : public Gtk::VBox
{
	public:
		NovaPage();
		~NovaPage();
	
		/*! \fn virtual bool save() = 0;
		* \brief Save the current document
		*/
		virtual bool save() = 0;
	
		/*! \fn virtual bool save_as(std::string file) = 0;
		* \brief Save the current document as
		*/
		virtual bool save_as(Glib::ustring file) = 0;
		
		/*! \fn virtual void set_size(int width, int height) = 0;
		* \brief Set the document page size
		*/
		virtual void set_size(int width, int height) = 0;
	
		/*! \fn bool is_modified();
		* \brief Is the document modified since last saved
		*/
		bool is_modified();
		
		/*! \fn virtual bool print() = 0;
		* \brief Print the document
		*/
		virtual bool print() = 0;
		
		/*! \fn virtual bool open(std::string file) = 0;
		* \brief Open and load a document from disk
		*/
		virtual bool open(Glib::ustring file) = 0;
		
		/*! \fn bool is_file_valid();
		* \brief Does the document have a valid filename for saving
		*/
		bool is_file_valid();
	
	protected:
		bool m_is_modified;		/*!< Modified since last saved */
		Glib::ustring m_filename;	/*!< Document filename */
		bool m_is_file_valid;	/*!< Has valid filename for saving */
	
};

};

#endif
