// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2003 Liam Girdwood  

#include "constellation.hh"
#include <libgnomecanvasmm/line.h>

/*! \namespace Vega
* \brief Nova Virtual Sky Engine
*/
namespace Vega
{

Constellation::ConstName Constellation::const_names[NUM_CONSTEL] = {
	AND, "And", "Andromeda", "Andromedae",
	ANT, "Ant", "Antila", "Antliae",
	APS, "Aps", "Apus", "Apodis",
	AQL, "Aql", "Aquila", "Aquilae",
	AQR, "Aqr", "Aquarius", "Aquarii",
	ARI, "Ari", "Aries", "Arietis",
	ARA, "Ara", "Ara", "Arae",
	AUR, "Aur", "Auriga", "Aurigae",
	BOO, "Boo", "Bootes", "Bootis",
	CAE, "Cae", "Caelum", "Caeli",
	CAM, "Cam", "Camelopardis", "Camelopardalis",
	CNC, "Cnc", "Cancer", "Cancri",	
	CAP, "Cap", "Capricorn", "Capricorni",
	CAR, "Car", "Carina", "Carinae",
	CAS, "Cas", "Cassiopea", "Cassiopeiae",
	CEN, "Cen", "Centurus", "Centauri",
	CEP, "Cep", "Cephus", "Cephei",
	CET, "Cet", "Cetus", "Ceti",
	CHA, "Cha", "Chamaeleon", "Chamaeleontis",
	CIR, "Cir", "Circinus", "Circini",
	CMA, "CMa", "Canis Major", "Canis Majoris",
	CMI, "CMi", "Canis Minor", "Canis Minoris",
	CNC, "Cnc", "Cancer", "Cancri",
	COL, "Col", "Columba", "Columbae",
	COM, "Com", "Coma Berenices", "Comae Berenices",
	CRA, "CrA", "Corona Austrinae", "Coronae Austrinae",
	CRB, "CrB", "Corona Borealis","Coronae Borealis",
	CRT, "Crt", "Crater", "Crateris",
	CRU, "Cru", "Crux", "Crucis",
	CRV, "Crv", "Corvus","Corvi",
	CVN, "CVn", "Canes Venatici", "Canum Venaticorum",
	CYG, "Cyg", "Cygnus", "Cygni",
	DEL, "Del", "Delphinus", "Delphini",
	DOR, "Dor", "Dorado", "Doradus",
	DRA, "Dra", "Draco", "Draconis",
	EQU, "Equ", "Equuleus", "Equulei",
	ERI, "Eri", "Eridanus", "Eridani",
	FOR, "For", "Fornax", "Fornacis",
	GEM, "Gem", "Gemini", "Geminorum",
	GRU, "Gru", "Grus", "Gruis",
	HER, "Her", "Hercules", "Herculis",
	HOR, "Hor", "Horologium", "Horologii",
	HYA, "Hya", "Hydra", "Hydrae",
	HYI, "Hyi", "Hydrus", "Hydri",
	IND, "Ind", "Indus", "Indi",
	LAC, "Lac", "Lacerta", "Lacertae",
	LEO, "Leo", "Leo", "Leonis",
	LEP, "Lep", "Lepus", "Leporis",
	LIB, "Lib", "Libra", "Librae",
	LMI, "LMi", "Leo Minor", "Leonis Minoris",
	LUP, "Lup", "Lupus", "Lupi",
	LYN, "Lyn", "Lynx", "Lyncis",
	LYR, "Lyr", "Lyra", "Lyrae",
	MEN, "Men", "Mensa", "Mensae",
	MIC, "Mic", "Microscopium", "Microscopii",
	MON, "Mon", "Monoceros", "Monocerotis",
	MUS, "Mus", "Musca", "Muscae",
	NOR, "Nor", "Norma", "Normae",
	OCT, "Oct", "Octans", "Octantis",
	OPH, "Oph", "Ophiuchus", "Ophiuchi",
	ORI, "Ori", "Orion", "Orionis",
	PAV, "Pav", "Pavon", "Pavonis",
	PEG, "Peg", "Pegasus", "Pegasi",
	PER, "Per", "Perseus", "Persei",
	PHE, "Phe", "Phoenix", "Phoenicis",
	PIC, "Pic", "Pictor", "Pictoris",
	PSA, "PsA", "Piscis Austrinus", "Piscis Austrini",
	PSC, "Psc", "Piscis", "Piscium",
	PUP, "Pup", "Puppis", "Puppis",
	PYX, "Pyx", "Pyxis", "Pyxidis",
	RET, "Ret", "Reticulum", "Reticuli",
	SCL, "Scl", "Sculptor", "Sculptoris",
	SCO, "Sco", "Scorpio", "Scorpii",
	SCT, "Sct", "Scutum", "Scuti",
	SER, "Ser", "Serpens", "Serpentis",
	SEX, "Sex", "Sextans", "Sextantis",
	SGE, "Sge", "Sagitta", "Sagittae",
	SGR, "Sgr", "Sagittarius", "Sagittarii",
	TAU, "Tau", "Taurus", "Tauri",
	TEL, "Tel", "Telescopium", "Telescopii",
	TRA, "TrA", "Triangulum Australe", "Trianguli Australis",
	TRI, "Tri", "Triangulum", "Trianguli",
	TUC, "Tuc", "Tucana", "Tucanae",
	UMA, "UMa", "Ursa Major", "Ursae Majoris",
	UMI, "UMi", "Ursa Minor", "Ursae Minoris",
	VEL, "Vel", "Vela", "Velorum",
	VIR, "Vir", "Virgo", "Virginis",
	VOL, "Vol", "Volans", "Volantis",
	VUL, "Vul", "Vulpecula", "Vulpeculae"
};


Constellation::ConstLine Constellation::const_lines[NUM_CONST_LINES] = {
	AND, 17.415000, 35.610000 ,30.975000, 42.330000,
	AND, 2.100000, 29.080000 ,9.825000, 30.860000,
	AND, 345.465000, 42.330000 ,354.390000, 46.440000,
	AND, 354.390000, 46.440000 ,14.190000, 38.500000,
	AND, 9.225000, 33.710000 ,2.100000, 29.080000,
	AND, 9.825000, 30.860000 ,17.415000, 35.610000,
	AND, 14.190000, 38.500000 ,17.370000, 47.250000,
	AND, 14.190000, 38.500000 ,9.225000, 33.710000,
	ANT, 156.795000, -31.060000 ,164.175000, -37.130000,
	ANT, 156.795000, -31.060000 ,142.290000, -35.950000,
	APS, 221.970000, -79.050000 ,246.720000, -78.730000,
	APS, 245.070000, -78.700000 ,248.370000, -78.890000,
	APS, 245.070000, -78.700000 ,250.770000, -77.510000,
	APS, 248.370000, -78.890000 ,250.770000, -77.510000,
	AQL, 284.895000, 15.060000 ,286.350000, 13.860000,
	AQL, 285.420000, -5.730000 ,286.545000, -4.880000,
	AQL, 286.350000, 13.860000 ,296.565000, 10.610000,
	AQL, 286.545000, -4.880000 ,291.375000, 3.110000,
	AQL, 291.375000, 3.110000 ,296.565000, 10.610000,
	AQL, 294.165000, -1.280000 ,286.545000, -4.880000,
	AQL, 296.565000, 10.610000 ,297.690000, 8.860000,
	AQL, 297.690000, 8.860000 ,298.815000, 6.400000,
	AQL, 298.110000, 1.000000 ,294.165000, -1.280000,
	AQL, 298.815000, 6.400000 ,302.820000, -0.810000,
	AQL, 302.820000, -0.810000 ,298.110000, 1.000000,
	AQR, 311.910000, -9.490000 ,322.890000, -5.560000,
	AQR, 322.890000, -5.560000 ,330.825000, -2.150000,
	AQR, 330.825000, -2.150000 ,335.415000, -1.380000,
	AQR, 335.415000, -1.380000 ,337.185000, -0.010000,
	AQR, 337.185000, -0.010000 ,336.315000, 1.380000,
	AQR, 337.185000, -0.010000 ,338.850000, -0.110000,
	AQR, 337.185000, -0.010000 ,343.140000, -7.580000,
	AQR, 342.390000, -13.590000 ,343.650000, -15.810000,
	AQR, 343.140000, -7.580000 ,342.390000, -13.590000,
	AQR, 343.650000, -15.810000 ,347.340000, -21.160000,
	AQR, 347.340000, -21.160000 ,351.495000, -20.640000,
	AQR, 348.570000, -6.050000 ,343.140000, -7.580000,
	AQR, 349.740000, -9.610000 ,348.570000, -6.050000,
	AQR, 351.495000, -20.640000 ,356.490000, -18.680000,
	AQR, 355.665000, -14.540000 ,349.740000, -9.610000,
	AQR, 356.490000, -18.680000 ,355.665000, -14.540000,
	ARA, 254.640000, -55.980000 ,252.450000, -59.030000,
	ARA, 254.640000, -55.980000 ,254.895000, -53.160000,
	ARA, 261.315000, -55.530000 ,254.640000, -55.980000,
	ARA, 261.315000, -55.530000 ,261.345000, -56.380000,
	ARA, 261.345000, -56.380000 ,262.770000, -60.680000,
	ARA, 262.935000, -49.880000 ,261.315000, -55.530000,
	ARA, 271.635000, -50.100000 ,262.935000, -49.880000,
	ARI, 28.365000, 19.290000 ,28.650000, 20.790000,
	ARI, 28.650000, 20.790000 ,31.785000, 23.460000,
	ARI, 31.785000, 23.460000 ,47.895000, 19.730000,
	AUR, 74.235000, 33.160000 ,76.620000, 41.230000,
	AUR, 76.620000, 41.230000 ,79.170000, 45.990000,
	AUR, 79.170000, 45.990000 ,89.865000, 54.280000,
	AUR, 81.570000, 28.600000 ,74.235000, 33.160000,
	AUR, 89.865000, 44.950000 ,79.170000, 45.990000,
	AUR, 89.865000, 44.950000 ,89.910000, 37.210000,
	AUR, 89.865000, 54.280000 ,89.970000, 45.930000,
	AUR, 89.910000, 37.210000 ,81.570000, 28.600000,
	AUR, 89.970000, 45.930000 ,89.865000, 44.950000,
	BOO, 208.665000, 18.390000 ,207.375000, 15.790000,
	BOO, 213.915000, 19.180000 ,208.665000, 18.390000,
	BOO, 213.915000, 19.180000 ,217.935000, 30.360000,
	BOO, 213.915000, 19.180000 ,220.260000, 13.730000,
	BOO, 214.095000, 46.080000 ,216.300000, 51.840000,
	BOO, 217.935000, 30.360000 ,218.010000, 38.300000,
	BOO, 218.010000, 38.300000 ,214.095000, 46.080000,
	BOO, 218.010000, 38.300000 ,225.465000, 40.380000,
	BOO, 221.250000, 27.060000 ,213.915000, 19.180000,
	BOO, 225.465000, 40.380000 ,228.870000, 33.310000,
	BOO, 228.870000, 33.310000 ,221.250000, 27.060000,
	CAE, 67.695000, -44.940000 ,70.140000, -41.860000,
	CAE, 70.140000, -41.860000 ,70.515000, -37.140000,
	CAE, 70.515000, -37.140000 ,76.095000, -35.480000,
	CAM, 57.600000, 71.330000 ,73.485000, 66.350000,
	CAM, 73.485000, 66.350000 ,75.840000, 60.440000,
	CAM, 73.485000, 66.350000 ,93.195000, 65.710000,
	CAM, 75.840000, 60.440000 ,74.310000, 53.750000,
	CAM, 93.195000, 65.710000 ,103.425000, 68.880000,
	CAP, 304.395000, -12.490000 ,305.235000, -14.780000,
	CAP, 305.235000, -14.780000 ,311.520000, -25.260000,
	CAP, 311.520000, -25.260000 ,312.945000, -26.910000,
	CAP, 312.945000, -26.910000 ,316.770000, -25.000000,
	CAP, 316.470000, -17.230000 ,304.515000, -12.540000,
	CAP, 316.770000, -25.000000 ,321.660000, -22.410000,
	CAP, 320.550000, -16.830000 ,316.470000, -17.230000,
	CAP, 321.660000, -22.410000 ,324.270000, -19.460000,
	CAP, 324.270000, -19.460000 ,326.745000, -16.130000,
	CAP, 325.020000, -16.660000 ,320.550000, -16.830000,
	CAP, 326.745000, -16.130000 ,325.020000, -16.660000,
	CAR, 153.420000, -70.030000 ,138.285000, -69.710000,
	CAR, 156.840000, -57.630000 ,157.995000, -61.680000,
	CAR, 157.995000, -61.680000 ,160.740000, -64.400000,
	CAR, 160.740000, -64.400000 ,153.420000, -70.030000,
	CAR, 95.985000, -52.700000 ,119.190000, -52.980000,
	CAR, 119.190000, -52.980000 ,125.610000, -59.510000,
	CAR, 125.610000, -59.510000 ,137.745000, -58.960000,
	CAR, 125.610000, -59.510000 ,140.520000, -55.010000,
	CAR, 138.285000, -69.710000 ,146.775000, -65.060000,
	CAR, 139.275000, -59.280000 ,156.840000, -57.630000,
	CAR, 146.775000, -65.060000 ,139.275000, -59.280000,
	CAS, 21.450000, 60.230000 ,28.590000, 63.660000,
	CAS, 2.295000, 59.140000 ,10.125000, 56.530000,
	CAS, 10.125000, 56.530000 ,14.160000, 60.710000,
	CAS, 14.160000, 60.710000 ,21.450000, 60.230000,
	CEN, 170.250000, -54.480000 ,182.100000, -50.710000,
	CEN, 173.940000, -63.010000 ,170.250000, -54.480000,
	CEN, 182.100000, -50.710000 ,190.365000, -48.960000,
	CEN, 190.365000, -48.960000 ,200.145000, -36.710000,
	CEN, 200.145000, -36.710000 ,211.665000, -36.360000,
	CEN, 204.960000, -53.460000 ,190.365000, -48.960000,
	CEN, 204.960000, -53.460000 ,210.945000, -60.360000,
	CEN, 208.860000, -47.280000 ,204.960000, -53.460000,
	CEN, 210.945000, -60.360000 ,219.885000, -60.830000,
	CEN, 211.665000, -36.360000 ,218.865000, -42.140000,
	CEN, 218.865000, -42.140000 ,208.860000, -47.280000,
	CEN, 218.865000, -42.140000 ,224.790000, -42.090000,
	CEP, 319.650000, 62.580000 ,332.715000, 58.200000,
	CEP, 322.170000, 70.560000 ,319.650000, 62.580000,
	CEP, 322.170000, 70.560000 ,342.420000, 66.200000,
	CEP, 332.715000, 58.200000 ,342.420000, 66.200000,
	CEP, 342.420000, 66.200000 ,354.825000, 77.630000,
	CEP, 354.825000, 77.630000 ,322.170000, 70.560000,
	CET, 17.145000, -10.180000 ,20.985000, -8.180000,
	CET, 20.985000, -8.180000 ,27.870000, -10.330000,
	CET, 26.010000, -15.930000 ,30.000000, -21.080000,
	CET, 27.870000, -10.330000 ,26.010000, -15.930000,
	CET, 27.870000, -10.330000 ,34.815000, -2.980000,
	CET, 27.870000, -10.330000 ,41.010000, -13.860000,
	CET, 34.815000, -2.980000 ,39.870000, 0.330000,
	CET, 37.050000, 8.460000 ,40.815000, 3.230000,
	CET, 39.870000, 0.330000 ,40.815000, 3.230000,
	CET, 40.815000, 3.230000 ,45.570000, 4.080000,
	CET, 41.220000, 10.110000 ,37.050000, 8.460000,
	CET, 44.925000, 8.890000 ,41.220000, 10.110000,
	CET, 45.570000, 4.080000 ,44.925000, 8.890000,
	CET, 4.845000, -8.810000 ,10.890000, -17.980000,
	CET, 10.890000, -17.980000 ,17.145000, -10.180000,
	CIR, 220.620000, -64.980000 ,229.365000, -58.790000,
	CIR, 220.620000, -64.980000 ,230.835000, -59.310000,
	CMA, 101.265000, -16.710000 ,95.670000, -17.950000,
	CMA, 101.265000, -16.710000 ,105.735000, -23.830000,
	CMA, 104.640000, -28.960000 ,95.070000, -30.060000,
	CMA, 105.420000, -27.930000 ,104.640000, -28.960000,
	CMA, 105.735000, -23.830000 ,107.100000, -26.390000,
	CMA, 105.945000, -15.630000 ,101.265000, -16.710000,
	CMA, 107.100000, -26.390000 ,105.420000, -27.930000,
	CMA, 107.100000, -26.390000 ,111.015000, -29.300000,
	CMI, 114.810000, 5.210000 ,111.765000, 8.280000,
	CNC, 130.815000, 21.460000 ,131.670000, 28.760000,
	CNC, 131.160000, 18.140000 ,124.125000, 9.180000,
	CNC, 131.160000, 18.140000 ,130.815000, 21.460000,
	CNC, 134.610000, 11.850000 ,131.160000, 18.140000,
	COL, 82.800000, -35.460000 ,84.900000, -34.060000,
	COL, 84.900000, -34.060000 ,87.735000, -35.760000,
	COL, 87.735000, -35.760000 ,89.370000, -35.280000,
	COL, 87.735000, -35.760000 ,89.775000, -42.810000,
	COL, 89.370000, -35.280000 ,95.520000, -33.430000,
	CRA, 164.940000, -18.290000 ,162.390000, -16.190000,
	CRA, 164.940000, -18.290000 ,170.520000, -16.220000,
	CRA, 167.925000, -22.830000 ,164.940000, -18.290000,
	CRA, 169.815000, -14.780000 ,171.135000, -10.860000,
	CRA, 171.135000, -10.860000 ,174.165000, -9.800000,
	CRA, 171.210000, -17.680000 ,169.815000, -14.780000,
	CRA, 176.190000, -18.340000 ,171.210000, -17.680000,
	CRA, 178.995000, -17.140000 ,176.190000, -18.340000,
	CRA, 278.370000, -42.310000 ,282.195000, -43.680000,
	CRA, 282.195000, -43.680000 ,285.765000, -42.090000,
	CRA, 285.765000, -42.090000 ,287.070000, -40.500000,
	CRA, 286.590000, -37.060000 ,284.670000, -37.100000,
	CRA, 287.070000, -40.500000 ,287.490000, -39.330000,
	CRA, 287.370000, -37.890000 ,286.590000, -37.060000,
	CRA, 287.490000, -39.330000 ,287.370000, -37.890000,
	CRU, 187.785000, -57.110000 ,186.645000, -63.090000,
	CRU, 191.910000, -59.680000 ,183.765000, -58.750000,
	CRV, 182.100000, -24.730000 ,182.520000, -22.610000,
	CRV, 182.520000, -22.610000 ,188.595000, -23.400000,
	CRV, 183.945000, -17.550000 ,182.520000, -22.610000,
	CRV, 187.470000, -16.510000 ,183.945000, -17.550000,
	CRV, 188.595000, -23.400000 ,187.470000, -16.510000,
	CVN, 193.995000, 38.310000 ,188.415000, 41.350000,
	CVN, 193.995000, 38.310000 ,199.365000, 40.560000,
	CYG, 299.070000, 35.080000 ,292.665000, 27.960000,
	CYG, 305.550000, 40.250000 ,296.250000, 45.130000,
	CYG, 305.550000, 40.250000 ,299.070000, 35.080000,
	CYG, 305.550000, 40.250000 ,311.550000, 33.960000,
	CYG, 310.350000, 45.280000 ,305.550000, 40.250000,
	DEL, 309.375000, 14.600000 ,308.295000, 11.290000,
	DEL, 309.375000, 14.600000 ,309.900000, 15.910000,
	DEL, 309.900000, 15.910000 ,311.670000, 16.110000,
	DEL, 310.875000, 15.060000 ,309.375000, 14.600000,
	DEL, 311.670000, 16.110000 ,310.875000, 15.060000,
	DOR, 68.490000, -55.040000 ,63.990000, -51.480000,
	DOR, 83.400000, -62.480000 ,68.490000, -55.040000,
	DOR, 86.190000, -65.730000 ,83.400000, -62.480000,
	DRA, 188.370000, 69.780000 ,172.845000, 69.330000,
	DRA, 211.095000, 64.380000 ,188.370000, 69.780000,
	DRA, 231.210000, 58.960000 ,211.095000, 64.380000,
	DRA, 240.465000, 58.560000 ,231.210000, 58.960000,
	DRA, 245.985000, 61.510000 ,240.465000, 58.560000,
	DRA, 257.190000, 65.710000 ,245.985000, 61.510000,
	DRA, 257.190000, 65.710000 ,275.190000, 71.330000,
	DRA, 262.590000, 52.300000 ,263.040000, 55.180000,
	DRA, 263.040000, 55.180000 ,268.365000, 56.860000,
	DRA, 268.365000, 56.860000 ,269.145000, 51.480000,
	DRA, 268.365000, 56.860000 ,282.795000, 59.380000,
	DRA, 269.145000, 51.480000 ,262.590000, 52.300000,
	DRA, 275.190000, 71.330000 ,288.135000, 67.660000,
	DRA, 275.265000, 72.730000 ,257.190000, 65.710000,
	DRA, 282.795000, 59.380000 ,300.690000, 67.860000,
	DRA, 288.135000, 67.660000 ,290.160000, 65.710000,
	DRA, 288.870000, 73.340000 ,275.265000, 72.730000,
	DRA, 290.160000, 65.710000 ,268.365000, 56.860000,
	DRA, 297.045000, 70.260000 ,288.870000, 73.340000,
	DRA, 300.690000, 67.860000 ,297.045000, 70.260000,
	EQU, 318.615000, 9.990000 ,317.565000, 10.130000,
	EQU, 318.945000, 5.250000 ,318.615000, 9.990000,
	ERI, 24.420000, -57.230000 ,28.995000, -51.610000,
	ERI, 28.995000, -51.610000 ,34.110000, -51.510000,
	ERI, 34.110000, -51.510000 ,36.735000, -47.690000,
	ERI, 36.735000, -47.690000 ,39.945000, -42.880000,
	ERI, 39.945000, -42.880000 ,40.170000, -39.850000,
	ERI, 40.170000, -39.850000 ,44.565000, -40.290000,
	ERI, 41.010000, -13.860000 ,44.085000, -8.900000,
	ERI, 41.265000, -18.560000 ,41.010000, -13.860000,
	ERI, 41.265000, -18.560000 ,45.600000, -23.610000,
	ERI, 44.085000, -8.900000 ,48.945000, -8.810000,
	ERI, 44.565000, -40.290000 ,55.695000, -37.310000,
	ERI, 45.600000, -23.610000 ,49.860000, -21.750000,
	ERI, 48.945000, -8.810000 ,53.220000, -9.440000,
	ERI, 49.860000, -21.750000 ,53.445000, -21.630000,
	ERI, 53.220000, -9.440000 ,55.785000, -9.760000,
	ERI, 53.445000, -21.630000 ,56.685000, -23.240000,
	ERI, 55.785000, -9.760000 ,56.520000, -12.100000,
	ERI, 56.520000, -12.100000 ,59.490000, -13.510000,
	ERI, 56.685000, -23.240000 ,58.425000, -24.610000,
	ERI, 57.150000, -37.610000 ,55.695000, -37.310000,
	ERI, 58.425000, -24.610000 ,59.970000, -24.010000,
	ERI, 59.490000, -13.510000 ,63.375000, -7.250000,
	ERI, 59.970000, -24.010000 ,68.370000, -29.760000,
	ERI, 63.375000, -7.250000 ,69.060000, -3.350000,
	ERI, 64.470000, -33.800000 ,57.150000, -37.610000,
	ERI, 66.000000, -34.010000 ,64.470000, -33.800000,
	ERI, 68.370000, -29.760000 ,68.895000, -30.560000,
	ERI, 68.895000, -30.560000 ,66.000000, -34.010000,
	ERI, 69.060000, -3.350000 ,71.370000, -3.250000,
	ERI, 71.370000, -3.250000 ,76.950000, -5.080000,
	GEM, 93.720000, 22.490000 ,91.020000, 23.260000,
	GEM, 95.745000, 22.510000 ,93.720000, 22.490000,
	GEM, 99.420000, 16.400000 ,106.020000, 20.560000,
	GEM, 100.965000, 25.130000 ,95.745000, 22.510000,
	GEM, 101.325000, 12.900000 ,99.420000, 16.400000,
	GEM, 106.020000, 20.560000 ,110.010000, 21.980000,
	GEM, 110.010000, 21.980000 ,116.325000, 28.030000,
	GEM, 113.640000, 31.880000 ,100.965000, 25.130000,
	GEM, 116.325000, 28.030000 ,113.640000, 31.880000,
	GRU, 328.470000, -37.360000 ,331.515000, -39.550000,
	GRU, 331.515000, -39.550000 ,333.900000, -41.350000,
	GRU, 333.900000, -41.350000 ,337.320000, -43.500000,
	GRU, 337.320000, -43.500000 ,332.040000, -46.960000,
	GRU, 337.320000, -43.500000 ,340.665000, -46.880000,
	GRU, 340.665000, -46.880000 ,342.150000, -51.310000,
	GRU, 340.665000, -46.880000 ,347.595000, -45.250000,
	GRU, 342.150000, -51.310000 ,345.225000, -52.740000,
	GRU, 347.595000, -45.250000 ,346.710000, -43.510000,
	HER, 242.190000, 44.930000 ,238.170000, 42.440000,
	HER, 244.920000, 46.310000 ,242.190000, 44.930000,
	HER, 247.545000, 21.480000 ,245.475000, 19.140000,
	HER, 248.520000, 42.430000 ,244.920000, 46.310000,
	HER, 250.320000, 31.590000 ,247.545000, 21.480000,
	HER, 250.320000, 31.590000 ,250.710000, 38.910000,
	HER, 250.710000, 38.910000 ,248.520000, 42.430000,
	HER, 250.710000, 38.910000 ,258.750000, 36.810000,
	HER, 255.075000, 30.930000 ,250.320000, 31.590000,
	HER, 258.645000, 14.380000 ,258.750000, 24.830000,
	HER, 258.750000, 24.830000 ,255.075000, 30.930000,
	HER, 258.750000, 24.830000 ,262.665000, 26.110000,
	HER, 258.750000, 36.810000 ,255.075000, 30.930000,
	HER, 258.750000, 36.810000 ,260.910000, 37.140000,
	HER, 258.750000, 36.810000 ,264.870000, 46.000000,
	HER, 260.910000, 37.140000 ,269.070000, 37.250000,
	HER, 262.665000, 26.110000 ,266.610000, 27.710000,
	HER, 266.610000, 27.710000 ,269.445000, 29.250000,
	HER, 269.445000, 29.250000 ,271.860000, 28.760000,
	HOR, 39.345000, -52.540000 ,40.170000, -54.550000,
	HOR, 40.170000, -54.550000 ,45.900000, -59.730000,
	HOR, 40.650000, -50.790000 ,39.345000, -52.540000,
	HOR, 45.900000, -59.730000 ,44.685000, -64.060000,
	HOR, 63.495000, -42.300000 ,40.650000, -50.790000,
	HYA, 151.260000, -13.060000 ,147.870000, -14.840000,
	HYA, 152.640000, -12.350000 ,151.260000, -13.060000,
	HYA, 156.525000, -16.830000 ,152.640000, -12.350000,
	HYA, 162.390000, -16.190000 ,156.525000, -16.830000,
	HYA, 173.235000, -31.840000 ,162.390000, -16.190000,
	HYA, 178.215000, -33.890000 ,173.235000, -31.840000,
	HYA, 199.710000, -23.160000 ,178.215000, -33.890000,
	HYA, 211.590000, -26.680000 ,199.710000, -23.160000,
	HYA, 129.420000, 5.700000 ,129.690000, 3.330000,
	HYA, 129.690000, 3.330000 ,130.785000, 3.390000,
	HYA, 130.785000, 3.390000 ,133.845000, 5.950000,
	HYA, 131.685000, 6.410000 ,129.420000, 5.700000,
	HYA, 133.845000, 5.950000 ,131.685000, 6.410000,
	HYA, 138.585000, 2.310000 ,133.845000, 5.950000,
	HYA, 141.900000, -8.660000 ,144.960000, -1.150000,
	HYA, 144.960000, -1.150000 ,138.585000, 2.310000,
	HYA, 147.870000, -14.840000 ,141.900000, -8.660000,
	HYI, 29.700000, -61.560000 ,6.450000, -77.240000,
	HYI, 39.900000, -68.260000 ,29.700000, -61.560000,
	HYI, 56.790000, -74.230000 ,39.900000, -68.260000,
	HYI, 6.450000, -77.240000 ,56.790000, -74.230000,
	IND, 309.390000, -47.280000 ,319.965000, -53.440000,
	IND, 319.965000, -53.440000 ,313.695000, -58.440000,
	IND, 319.965000, -53.440000 ,329.475000, -55.000000,
	LAC, 335.235000, 46.530000 ,340.110000, 44.280000,
	LAC, 335.895000, 52.230000 ,337.815000, 50.280000,
	LAC, 336.120000, 49.480000 ,337.365000, 47.690000,
	LAC, 337.365000, 47.690000 ,335.235000, 46.530000,
	LAC, 337.815000, 50.280000 ,336.120000, 49.480000,
	LAC, 340.110000, 44.280000 ,333.990000, 37.750000,
	LEO, 151.815000, 16.760000 ,154.995000, 19.850000,
	LEO, 152.100000, 11.960000 ,151.815000, 16.760000,
	LEO, 154.170000, 23.410000 ,148.200000, 26.000000,
	LEO, 154.995000, 19.850000 ,154.170000, 23.410000,
	LEO, 168.525000, 20.510000 ,168.540000, 15.430000,
	LEO, 168.540000, 15.430000 ,152.100000, 11.960000,
	LEO, 168.540000, 15.430000 ,177.270000, 14.560000,
	LEO, 177.270000, 14.560000 ,168.525000, 20.510000,
	LEO, 148.200000, 26.000000 ,146.460000, 23.760000,
	LEP, 82.035000, -20.760000 ,76.365000, -22.360000,
	LEP, 82.035000, -20.760000 ,86.115000, -22.440000,
	LEP, 83.175000, -17.810000 ,78.210000, -16.190000,
	LEP, 83.175000, -17.810000 ,82.035000, -20.760000,
	LEP, 86.115000, -22.440000 ,87.825000, -20.880000,
	LEP, 86.745000, -14.810000 ,83.175000, -17.810000,
	LEP, 87.825000, -20.880000 ,83.175000, -17.810000,
	LEP, 89.085000, -14.160000 ,86.745000, -14.810000,
	LIB, 222.720000, -16.050000 ,229.245000, -9.380000,
	LIB, 226.020000, -25.280000 ,222.720000, -16.050000,
	LIB, 226.020000, -25.280000 ,234.240000, -28.130000,
	LIB, 229.245000, -9.380000 ,233.865000, -14.780000,
	LIB, 233.865000, -14.780000 ,226.020000, -25.280000,
	LIB, 234.240000, -28.130000 ,234.660000, -29.780000,
	LMI, 156.960000, 36.700000 ,151.845000, 35.250000,
	LMI, 156.960000, 36.700000 ,163.320000, 34.210000,
	LUP, 220.470000, -47.380000 ,228.075000, -52.100000,
	LUP, 224.610000, -43.130000 ,220.470000, -47.380000,
	LUP, 228.075000, -52.100000 ,230.670000, -44.680000,
	LUP, 230.340000, -40.640000 ,224.610000, -43.130000,
	LUP, 230.445000, -36.260000 ,230.340000, -40.640000,
	LUP, 230.670000, -44.680000 ,233.760000, -41.160000,
	LUP, 235.290000, -44.660000 ,233.760000, -41.160000,
	LUP, 237.750000, -33.630000 ,230.445000, -36.260000,
	LUP, 241.650000, -36.800000 ,235.290000, -44.660000,
	LUP, 241.650000, -36.800000 ,237.750000, -33.630000,
	LYN, 94.890000, 59.010000 ,104.325000, 58.410000,
	LYN, 104.325000, 58.410000 ,111.660000, 49.210000,
	LYN, 111.660000, 49.210000 ,122.115000, 51.500000,
	LYN, 122.115000, 51.500000 ,125.700000, 43.180000,
	LYN, 139.695000, 36.800000 ,125.700000, 43.180000,
	LYN, 140.265000, 34.390000 ,139.695000, 36.800000,
	LYR, 279.225000, 38.780000 ,281.070000, 39.660000,
	LYR, 279.225000, 38.780000 ,281.190000, 37.590000,
	LYR, 281.190000, 37.590000 ,282.510000, 33.360000,
	LYR, 282.510000, 33.360000 ,284.715000, 32.680000,
	LYR, 283.620000, 36.900000 ,281.190000, 37.590000,
	LYR, 284.715000, 32.680000 ,283.620000, 36.900000,
	MEN, 73.785000, -74.930000 ,75.675000, -71.310000,
	MEN, 82.965000, -76.330000 ,73.785000, -74.930000,
	MEN, 92.550000, -74.740000 ,82.965000, -76.330000,
	MIC, 312.495000, -33.780000 ,315.315000, -32.250000,
	MIC, 315.315000, -32.250000 ,319.470000, -32.160000,
	MIC, 319.470000, -32.160000 ,320.190000, -40.810000,
	MON, 97.200000, -7.030000 ,93.720000, -6.260000,
	MON, 107.970000, -0.500000 ,97.200000, -7.030000,
	MON, 115.290000, -9.550000 ,107.970000, -0.500000,
	MON, 122.145000, -2.980000 ,115.290000, -9.550000,
	MUS, 176.385000, -66.730000 ,184.395000, -67.960000,
	MUS, 184.395000, -67.960000 ,189.300000, -69.130000,
	MUS, 188.115000, -72.130000 ,195.570000, -71.550000,
	MUS, 189.300000, -69.130000 ,188.115000, -72.130000,
	MUS, 191.565000, -68.100000 ,189.300000, -69.130000,
	MUS, 195.570000, -71.550000 ,191.565000, -68.100000,
	NOR, 240.795000, -49.230000 ,244.950000, -50.150000,
	NOR, 241.620000, -45.160000 ,240.795000, -49.230000,
	NOR, 244.950000, -50.150000 ,246.795000, -47.550000,
	NOR, 246.795000, -47.550000 ,241.620000, -45.160000,
	OCT, 216.720000, -83.660000 ,325.365000, -77.380000,
	OCT, 325.365000, -77.380000 ,341.520000, -81.380000,
	OCT, 341.520000, -81.380000 ,216.720000, -83.660000,
	OPH, 243.570000, -3.700000 ,244.560000, -4.690000,
	OPH, 244.560000, -4.690000 ,249.285000, -10.560000,
	OPH, 247.710000, 1.980000 ,243.570000, -3.700000,
	OPH, 249.285000, -10.560000 ,257.595000, -15.710000,
	OPH, 254.415000, 9.380000 ,247.710000, 1.980000,
	OPH, 257.595000, -15.710000 ,266.970000, 2.700000,
	OPH, 263.715000, 12.560000 ,254.415000, 9.380000,
	OPH, 265.860000, 4.560000 ,263.715000, 12.560000,
	OPH, 266.970000, 2.700000 ,265.860000, 4.560000,
	OPH, 266.970000, 2.700000 ,270.135000, 2.930000,
	OPH, 270.135000, 2.930000 ,271.365000, 2.500000,
	ORI, 72.450000, 6.960000 ,72.645000, 8.890000,
	ORI, 72.645000, 8.890000 ,73.125000, 14.250000,
	ORI, 72.795000, 5.600000 ,72.450000, 6.960000,
	ORI, 73.560000, 2.430000 ,72.795000, 5.600000,
	ORI, 74.625000, 1.710000 ,73.560000, 2.430000,
	ORI, 78.615000, -8.190000 ,86.940000, -9.660000,
	ORI, 79.395000, -6.850000 ,78.615000, -8.190000,
	ORI, 81.270000, 6.350000 ,74.625000, 1.710000,
	ORI, 81.270000, 6.350000 ,82.995000, -0.290000,
	ORI, 82.995000, -0.290000 ,79.395000, -6.850000,
	ORI, 83.685000, 9.480000 ,81.270000, 6.350000,
	ORI, 85.200000, -1.950000 ,88.785000, 7.400000,
	ORI, 86.940000, -9.660000 ,85.200000, -1.950000,
	ORI, 88.785000, 7.400000 ,83.685000, 9.480000,
	ORI, 88.785000, 7.400000 ,90.600000, 9.650000,
	ORI, 90.600000, 9.650000 ,91.890000, 14.760000,
	ORI, 90.600000, 9.650000 ,92.970000, 14.210000,
	ORI, 91.890000, 14.760000 ,88.590000, 20.280000,
	ORI, 92.970000, 14.210000 ,90.960000, 20.130000,
	PAV, 266.415000, -64.710000 ,280.740000, -71.430000,
	PAV, 280.740000, -71.430000 ,300.150000, -72.910000,
	PAV, 300.150000, -72.910000 ,311.250000, -66.200000,
	PAV, 302.160000, -66.180000 ,266.415000, -64.710000,
	PAV, 306.390000, -56.730000 ,311.250000, -66.200000,
	PAV, 311.250000, -66.200000 ,302.160000, -66.180000,
	PAV, 311.250000, -66.200000 ,321.585000, -65.360000,
	PEG, 2.100000, 29.080000 ,3.300000, 15.180000,
	PEG, 3.300000, 15.180000 ,346.185000, 15.200000,
	PEG, 331.740000, 25.340000 ,326.145000, 25.650000,
	PEG, 332.550000, 6.200000 ,326.040000, 9.880000,
	PEG, 340.365000, 10.830000 ,332.550000, 6.200000,
	PEG, 340.740000, 30.210000 ,332.490000, 33.180000,
	PEG, 341.610000, 23.560000 ,331.740000, 25.340000,
	PEG, 341.670000, 12.160000 ,340.365000, 10.830000,
	PEG, 342.495000, 24.600000 ,341.610000, 23.560000,
	PEG, 345.945000, 28.080000 ,2.100000, 29.080000,
	PEG, 345.945000, 28.080000 ,340.740000, 30.210000,
	PEG, 345.945000, 28.080000 ,342.495000, 24.600000,
	PEG, 346.185000, 15.200000 ,341.670000, 12.160000,
	PEG, 346.185000, 15.200000 ,345.945000, 28.080000,
	PER, 42.660000, 55.890000 ,43.560000, 52.760000,
	PER, 42.660000, 55.890000 ,46.200000, 53.500000,
	PER, 43.560000, 52.760000 ,47.265000, 49.610000,
	PER, 46.200000, 53.500000 ,51.060000, 49.860000,
	PER, 47.040000, 40.940000 ,46.290000, 38.830000,
	PER, 47.265000, 49.610000 ,47.370000, 44.840000,
	PER, 47.370000, 44.840000 ,47.040000, 40.940000,
	PER, 51.060000, 49.860000 ,55.710000, 47.780000,
	PER, 55.710000, 47.780000 ,56.295000, 42.580000,
	PER, 55.710000, 47.780000 ,62.175000, 47.710000,
	PER, 56.295000, 42.580000 ,59.475000, 40.010000,
	PER, 58.515000, 31.880000 ,56.070000, 32.280000,
	PER, 59.475000, 40.010000 ,59.745000, 35.780000,
	PER, 59.745000, 35.780000 ,58.515000, 31.880000,
	PER, 62.175000, 47.710000 ,63.720000, 48.410000,
	PER, 63.720000, 48.410000 ,61.650000, 50.350000,
	PHE, 16.515000, -46.710000 ,22.815000, -49.060000,
	PHE, 16.515000, -46.710000 ,6.570000, -42.300000,
	PHE, 17.085000, -55.250000 ,16.515000, -46.710000,
	PHE, 22.095000, -43.310000 ,16.515000, -46.710000,
	PHE, 22.815000, -49.060000 ,22.095000, -43.310000,
	PHE, 6.570000, -42.300000 ,2.340000, -45.740000,
	PIC, 87.450000, -56.160000 ,86.820000, -51.060000,
	PIC, 102.045000, -61.930000 ,87.450000, -56.160000,
	PSA, 326.220000, -33.030000 ,332.085000, -32.980000,
	PSA, 332.085000, -32.980000 ,337.860000, -32.340000,
	PSA, 337.860000, -32.340000 ,343.125000, -32.880000,
	PSA, 343.125000, -32.880000 ,343.965000, -32.530000,
	PSA, 343.965000, -32.530000 ,344.400000, -29.610000,
	PSA, 344.400000, -29.610000 ,340.170000, -27.050000,
	PSA, 344.400000, -29.610000 ,347.340000, -21.160000,
	PSC, 15.720000, 7.880000 ,12.165000, 7.580000,
	PSC, 18.420000, 24.580000 ,19.875000, 27.260000,
	PSC, 19.875000, 27.260000 ,17.910000, 30.080000,
	PSC, 22.875000, 15.350000 ,18.420000, 24.580000,
	PSC, 25.350000, 5.480000 ,15.720000, 7.880000,
	PSC, 26.340000, 9.150000 ,22.875000, 15.350000,
	PSC, 30.495000, 2.760000 ,25.350000, 5.480000,
	PSC, 30.495000, 2.760000 ,26.340000, 9.150000,
	PSC, 349.290000, 3.280000 ,345.960000, 3.810000,
	PSC, 349.290000, 3.280000 ,351.990000, 6.380000,
	PSC, 351.720000, 1.250000 ,349.290000, 3.280000,
	PSC, 351.990000, 6.380000 ,354.975000, 5.630000,
	PSC, 354.975000, 5.630000 ,355.500000, 1.780000,
	PSC, 355.500000, 1.780000 ,351.720000, 1.250000,
	PSC, 359.820000, 6.860000 ,354.975000, 5.630000,
	PSC, 12.165000, 7.580000 ,359.820000, 6.860000,
	PUP, 99.435000, -43.200000 ,102.465000, -50.610000,
	PUP, 102.465000, -50.610000 ,108.840000, -43.980000,
	PUP, 108.840000, -43.980000 ,99.435000, -43.200000,
	PUP, 108.840000, -43.980000 ,112.290000, -43.290000,
	PUP, 109.260000, -37.090000 ,120.885000, -40.000000,
	PUP, 112.290000, -43.290000 ,109.260000, -37.090000,
	PUP, 115.935000, -28.950000 ,120.885000, -40.000000,
	PUP, 117.315000, -24.860000 ,115.935000, -28.950000,
	PUP, 120.885000, -40.000000 ,112.290000, -43.290000,
	PUP, 121.875000, -24.290000 ,117.315000, -24.860000,
	PYX, 130.020000, -35.300000 ,130.890000, -33.180000,
	PYX, 130.890000, -33.180000 ,132.615000, -27.710000,
	RET, 56.040000, -64.800000 ,63.600000, -62.460000,
	RET, 59.670000, -61.390000 ,60.210000, -62.160000,
	RET, 60.210000, -62.160000 ,56.040000, -64.800000,
	RET, 63.600000, -62.460000 ,64.125000, -59.290000,
	RET, 64.125000, -59.290000 ,59.670000, -61.390000,
	SCL, 349.695000, -32.530000 ,357.225000, -28.130000,
	SCL, 353.250000, -37.810000 ,349.695000, -32.530000,
	SCL, 357.225000, -28.130000 ,14.640000, -29.350000,
	SCO, 240.060000, -22.610000 ,239.685000, -26.110000,
	SCO, 240.060000, -22.610000 ,241.350000, -19.800000,
	SCO, 240.060000, -22.610000 ,245.295000, -25.600000,
	SCO, 245.295000, -25.600000 ,247.350000, -26.430000,
	SCO, 247.350000, -26.430000 ,248.970000, -28.210000,
	SCO, 248.970000, -28.210000 ,252.540000, -34.300000,
	SCO, 252.540000, -34.300000 ,252.960000, -38.050000,
	SCO, 252.960000, -38.050000 ,253.635000, -42.360000,
	SCO, 253.635000, -42.360000 ,258.045000, -43.230000,
	SCO, 258.045000, -43.230000 ,264.315000, -42.990000,
	SCO, 263.400000, -37.100000 ,262.695000, -37.300000,
	SCO, 264.315000, -42.990000 ,266.895000, -40.130000,
	SCO, 265.620000, -39.030000 ,263.400000, -37.100000,
	SCO, 266.895000, -40.130000 ,265.620000, -39.030000,
	SCT, 277.290000, -14.560000 ,278.790000, -8.250000,
	SCT, 278.790000, -8.250000 ,281.790000, -4.740000,
	SER, 233.685000, 10.530000 ,236.070000, 6.430000,
	SER, 236.070000, 6.430000 ,237.690000, 4.480000,
	SER, 236.550000, 15.410000 ,233.685000, 10.530000,
	SER, 237.165000, 18.130000 ,235.395000, 19.660000,
	SER, 237.165000, 18.130000 ,236.550000, 15.410000,
	SER, 237.165000, 18.130000 ,237.825000, 20.980000,
	SER, 237.165000, 18.130000 ,239.115000, 15.660000,
	SER, 237.390000, -3.430000 ,243.570000, -3.700000,
	SER, 237.690000, 4.480000 ,237.390000, -3.430000,
	SER, 260.190000, -12.840000 ,257.595000, -15.710000,
	SER, 264.390000, -15.400000 ,260.190000, -12.840000,
	SER, 265.350000, -12.880000 ,264.390000, -15.400000,
	SER, 269.745000, -9.760000 ,265.350000, -12.880000,
	SER, 275.310000, -2.900000 ,269.745000, -9.760000,
	SER, 284.040000, 4.190000 ,275.310000, -2.900000,
	SEX, 151.965000, -0.360000 ,157.560000, -0.630000,
	SEX, 157.365000, -2.730000 ,148.110000, -8.090000,
	SEX, 157.560000, -0.630000 ,157.365000, -2.730000,
	SEX, 148.110000, -8.090000 ,151.965000, -0.360000,
	SGE, 296.835000, 18.530000 ,295.020000, 18.010000,
	SGE, 296.835000, 18.530000 ,295.245000, 17.480000,
	SGE, 299.700000, 19.490000 ,296.835000, 18.530000,
	SGR, 271.440000, -30.410000 ,276.045000, -34.380000,
	SGR, 275.250000, -29.830000 ,271.440000, -30.410000,
	SGR, 276.045000, -34.380000 ,275.250000, -29.830000,
	SGR, 276.045000, -34.380000 ,285.645000, -29.880000,
	SGR, 276.990000, -25.410000 ,275.250000, -29.830000,
	SGR, 281.415000, -26.980000 ,276.990000, -25.410000,
	SGR, 283.815000, -26.290000 ,281.415000, -26.980000,
	SGR, 283.815000, -26.290000 ,286.170000, -21.750000,
	SGR, 285.645000, -29.880000 ,281.415000, -26.980000,
	SGR, 285.645000, -29.880000 ,286.725000, -27.660000,
	SGR, 286.170000, -21.750000 ,284.415000, -21.100000,
	SGR, 286.170000, -21.750000 ,287.445000, -21.010000,
	SGR, 286.725000, -27.660000 ,283.815000, -26.290000,
	SGR, 287.445000, -21.010000 ,290.415000, -17.850000,
	SGR, 290.640000, -44.460000 ,290.970000, -40.610000,
	SGR, 290.970000, -40.610000 ,285.645000, -29.880000,
	TAU, 51.795000, 9.730000 ,51.195000, 9.030000,
	TAU, 60.165000, 12.480000 ,51.795000, 9.730000,
	TAU, 64.935000, 15.630000 ,60.165000, 12.480000,
	TAU, 65.715000, 17.550000 ,64.935000, 15.630000,
	TAU, 66.375000, 17.930000 ,65.715000, 17.550000,
	TAU, 67.140000, 15.960000 ,64.935000, 15.630000,
	TAU, 67.140000, 19.180000 ,66.375000, 17.930000,
	TAU, 68.970000, 16.510000 ,67.140000, 15.960000,
	TAU, 70.545000, 22.950000 ,67.140000, 19.180000,
	TAU, 81.570000, 28.600000 ,70.545000, 22.950000,
	TAU, 84.390000, 21.150000 ,68.970000, 16.510000,
	TEL, 276.750000, -45.960000 ,272.790000, -45.940000,
	TEL, 277.200000, -49.060000 ,276.750000, -45.960000,
	TRA, 229.710000, -68.680000 ,252.165000, -69.030000,
	TRA, 234.165000, -66.310000 ,229.710000, -68.680000,
	TRA, 238.770000, -63.430000 ,234.165000, -66.310000,
	TRA, 252.165000, -69.030000 ,238.770000, -63.430000,
	TRI, 28.275000, 29.580000 ,32.370000, 34.980000,
	TRI, 28.275000, 29.580000 ,34.320000, 33.850000,
	TRI, 32.370000, 34.980000 ,34.320000, 33.850000,
	TUC, 334.620000, -60.260000 ,336.825000, -64.960000,
	TUC, 349.335000, -58.230000 ,334.620000, -60.260000,
	TUC, 349.335000, -58.230000 ,7.860000, -62.950000,
	TUC, 359.970000, -65.580000 ,336.825000, -64.960000,
	TUC, 5.010000, -64.880000 ,359.970000, -65.580000,
	TUC, 7.860000, -62.950000 ,5.010000, -64.880000,
	UMA, 165.450000, 56.380000 ,165.915000, 61.740000,
	UMA, 165.915000, 61.740000 ,183.840000, 57.030000,
	UMA, 165.915000, 61.740000 ,142.875000, 63.060000,
	UMA, 167.415000, 44.500000 ,155.565000, 41.490000,
	UMA, 169.620000, 33.090000 ,169.545000, 31.530000,
	UMA, 176.490000, 47.780000 ,167.415000, 44.500000,
	UMA, 176.490000, 47.780000 ,169.620000, 33.090000,
	UMA, 178.440000, 53.690000 ,165.450000, 56.380000,
	UMA, 178.440000, 53.690000 ,176.490000, 47.780000,
	UMA, 183.840000, 57.030000 ,178.440000, 53.690000,
	UMA, 193.500000, 55.960000 ,183.840000, 57.030000,
	UMA, 200.970000, 54.930000 ,193.500000, 55.960000,
	UMA, 206.865000, 49.310000 ,200.970000, 54.930000,
	UMA, 134.790000, 48.050000 ,143.220000, 51.680000,
	UMA, 142.875000, 63.060000 ,127.575000, 60.710000,
	UMA, 143.220000, 51.680000 ,148.020000, 54.060000,
	UMA, 147.750000, 59.030000 ,142.875000, 63.060000,
	UMA, 148.020000, 54.060000 ,147.750000, 59.030000,
	UMI, 222.660000, 74.140000 ,230.160000, 71.830000,
	UMI, 230.160000, 71.830000 ,244.365000, 75.750000,
	UMI, 236.025000, 77.790000 ,222.660000, 74.140000,
	UMI, 244.365000, 75.750000 ,236.025000, 77.790000,
	UMI, 251.490000, 82.030000 ,236.025000, 77.790000,
	UMI, 263.040000, 86.580000 ,251.490000, 82.030000,
	UMI, 37.950000, 89.260000 ,263.040000, 86.580000,
	VEL, 161.685000, -49.410000 ,149.220000, -54.560000,
	VEL, 122.370000, -47.340000 ,136.995000, -43.430000,
	VEL, 131.160000, -54.690000 ,122.370000, -47.340000,
	VEL, 136.995000, -43.430000 ,140.520000, -55.010000,
	VEL, 136.995000, -43.430000 ,142.665000, -40.460000,
	VEL, 140.520000, -55.010000 ,131.160000, -54.690000,
	VEL, 149.220000, -54.560000 ,140.520000, -55.010000,
	VIR, 184.965000, -0.660000 ,177.675000, 1.760000,
	VIR, 190.410000, -1.450000 ,184.965000, -0.660000,
	VIR, 190.410000, -1.450000 ,201.300000, -11.160000,
	VIR, 193.890000, 3.400000 ,190.410000, -1.450000,
	VIR, 195.540000, 10.960000 ,193.890000, 3.400000,
	VIR, 197.490000, 17.530000 ,197.970000, 27.880000,
	VIR, 197.970000, 27.880000 ,186.720000, 28.260000,
	VIR, 201.300000, -11.160000 ,213.990000, -5.990000,
	VIR, 210.390000, 1.540000 ,203.670000, -0.600000,
	VIR, 213.990000, -5.990000 ,220.770000, -5.660000,
	VIR, 220.770000, -5.660000 ,221.535000, 1.900000,
	VIR, 221.535000, 1.900000 ,210.390000, 1.540000,
	VIR, 231.945000, 29.100000 ,233.670000, 26.710000,
	VIR, 233.220000, 31.360000 ,231.945000, 29.100000,
	VIR, 233.670000, 26.710000 ,235.665000, 26.300000,
	VIR, 235.665000, 26.300000 ,237.390000, 26.060000,
	VIR, 237.390000, 26.060000 ,239.400000, 26.880000,
	VIR, 239.400000, 26.880000 ,240.345000, 29.850000,
	VOL, 107.190000, -70.500000 ,109.185000, -67.940000,
	VOL, 109.185000, -67.940000 ,126.420000, -66.130000,
	VOL, 115.440000, -72.590000 ,107.190000, -70.500000,
	VOL, 121.965000, -68.610000 ,115.440000, -72.590000,
	VOL, 126.420000, -66.130000 ,121.965000, -68.610000,
	VOL, 135.585000, -66.390000 ,126.420000, -66.130000,
	VOL, 137.745000, -58.960000 ,139.275000, -59.280000,
	VUL, 292.170000, 24.660000 ,289.035000, 21.380000,
	VUL, 292.170000, 24.660000 ,298.365000, 24.080000
};

Constellation::ConstBound Constellation::const_bounds[NUM_CONST_BOUND] = {
	UMI, 0.000000, 360.000000 ,88.000000,
	UMI, 120.000000, 217.500000 ,86.500000,
	UMI, 315.000000, 345.000000 ,86.166700,
	UMI, 270.000000, 315.000000 ,86.000000,
	CEP, 0.000000, 120.000000 ,85.000000,
	CAM, 137.500500, 160.000500 ,82.000000,
	CEP, 0.000000, 75.000000 ,80.000000,
	CAM, 160.000500, 217.500000 ,80.000000,
	UMI, 262.500000, 270.000000 ,80.000000,
	DRA, 302.500500, 315.000000 ,80.000000,
	CEP, 0.000000, 52.624500 ,77.000000,
	CAM, 172.500000, 203.749500 ,77.000000,
	UMI, 247.999500, 262.500000 ,75.000000,
	CEP, 302.500500, 310.000500 ,75.000000,
	CAM, 119.500500, 137.500500 ,73.500000,
	DRA, 137.500500, 169.999500 ,73.500000,
	UMI, 195.000000, 247.999500 ,70.000000,
	CAS, 46.500000, 51.250500 ,68.000000,
	DRA, 306.250500, 310.000500 ,67.000000,
	DRA, 169.999500, 180.000000 ,66.500000,
	CEP, 0.000000, 4.999500 ,66.000000,
	UMI, 210.000000, 235.000500 ,66.000000,
	CEP, 353.749500, 360.000000 ,66.000000,
	DRA, 180.000000, 202.500000 ,64.000000,
	DRA, 202.500000, 216.250500 ,63.000000,
	CEP, 347.500500, 353.749500 ,63.000000,
	CAM, 91.500000, 105.000000 ,62.000000,
	DRA, 300.000000, 306.250500 ,61.500000,
	CEP, 308.050500, 309.000000 ,60.916700,
	CAM, 105.000000, 119.500500 ,60.000000,
	UMA, 119.500500, 126.250500 ,60.000000,
	DRA, 296.500500, 300.000000 ,59.500000,
	CEP, 300.000000, 308.050500 ,59.500000,
	CEP, 343.000500, 347.500500 ,59.083300,
	CAS, 0.000000, 36.499500 ,58.500000,
	DRA, 291.250500, 296.500500 ,58.000000,
	CAS, 25.500000, 28.624500 ,57.500000,
	CAS, 36.499500, 46.500000 ,57.000000,
	CAM, 46.500000, 47.500500 ,57.000000,
	CEP, 334.750500, 343.000500 ,56.250000,
	CAM, 75.000000, 91.500000 ,56.000000,
	UMA, 210.499500, 216.250500 ,55.500000,
	DRA, 216.250500, 291.250500 ,55.500000,
	CAM, 47.500500, 49.999500 ,55.000000,
	CEP, 331.999500, 334.750500 ,55.000000,
	CEP, 309.000000, 329.500500 ,54.833300,
	CAS, 0.000000, 25.500000 ,54.000000,
	LYN, 91.500000, 97.500000 ,54.000000,
	UMA, 181.249500, 202.500000 ,53.000000,
	DRA, 228.750000, 236.250000 ,53.000000,
	CEP, 329.500500, 331.999500 ,52.750000,
	CAM, 49.999500, 75.000000 ,52.500000,
	CAS, 343.000500, 349.999500 ,52.500000,
	DRA, 236.250000, 255.000000 ,51.500000,
	PER, 30.625500, 37.750500 ,50.500000,
	DRA, 255.000000, 273.499500 ,50.500000,
	CAS, 0.000000, 20.500500 ,50.000000,
	PER, 20.500500, 25.000500 ,50.000000,
	LYN, 97.500000, 102.000000 ,50.000000,
	CAS, 349.999500, 360.000000 ,50.000000,
	UMA, 202.500000, 210.499500 ,48.500000,
	CAS, 0.000000, 16.750500 ,48.000000,
	CAS, 353.749500, 360.000000 ,48.000000,
	HER, 272.625000, 273.499500 ,47.500000,
	DRA, 273.499500, 286.249500 ,47.500000,
	CYG, 286.249500, 287.500500 ,47.500000,
	PER, 25.000500, 30.625500 ,47.000000,
	UMA, 126.250500, 137.500500 ,47.000000,
	CAS, 2.500500, 13.000500 ,46.000000,
	UMA, 180.000000, 181.249500 ,45.000000,
	LYN, 102.000000, 110.500500 ,44.500000,
	CYG, 328.624500, 329.500500 ,44.000000,
	CYG, 328.125000, 328.624500 ,43.750000,
	CYG, 287.500500, 291.000000 ,43.500000,
	UMA, 137.500500, 152.500500 ,42.000000,
	UMA, 152.500500, 161.749500 ,40.000000,
	BOO, 231.499500, 236.250000 ,40.000000,
	HER, 236.250000, 244.999500 ,40.000000,
	LYN, 138.750000, 143.749500 ,39.750000,
	AND, 0.000000, 37.750500 ,36.750000,
	PER, 37.750500, 38.500500 ,36.750000,
	LYR, 290.374500, 291.000000 ,36.500000,
	PER, 67.500000, 70.375500 ,36.000000,
	CYG, 325.999500, 328.125000 ,36.000000,
	LAC, 328.125000, 330.000000 ,36.000000,
	AUR, 97.999500, 110.500500 ,35.500000,
	LYN, 110.500500, 116.250000 ,35.500000,
	AND, 0.000000, 30.000000 ,35.000000,
	LAC, 330.000000, 342.250500 ,35.000000,
	LAC, 342.250500, 343.000500 ,34.500000,
	AND, 343.000500, 352.500000 ,34.500000,
	PER, 38.500500, 40.750500 ,34.000000,
	UMA, 161.749500, 165.000000 ,34.000000,
	CVN, 180.000000, 184.999500 ,34.000000,
	LYN, 116.250000, 138.750000 ,33.500000,
	LMI, 138.750000, 148.249500 ,33.500000,
	AND, 10.750500, 21.124500 ,33.000000,
	BOO, 227.749500, 231.499500 ,33.000000,
	AND, 352.500000, 356.250000 ,32.083300,
	CVN, 184.999500, 198.750000 ,32.000000,
	AND, 356.250000, 360.000000 ,31.333300,
	CVN, 209.374500, 210.499500 ,30.750000,
	TRI, 36.250500, 40.750500 ,30.666700,
	PER, 40.750500, 67.500000 ,30.666700,
	AUR, 67.500000, 71.250000 ,30.000000,
	LYR, 272.625000, 290.374500 ,30.000000,
	UMA, 165.000000, 180.000000 ,29.000000,
	CYG, 295.000500, 313.750500 ,29.000000,
	AUR, 71.250000, 88.249500 ,28.500000,
	LMI, 148.249500, 157.500000 ,28.500000,
	CVN, 198.750000, 209.374500 ,28.500000,
	AND, 0.000000, 1.000500 ,28.000000,
	TRI, 21.124500, 25.000500 ,28.000000,
	AUR, 88.249500, 97.999500 ,28.000000,
	GEM, 118.249500, 120.000000 ,28.000000,
	CYG, 313.750500, 325.999500 ,28.000000,
	CYG, 288.874500, 295.000500 ,27.500000,
	TRI, 28.750500, 36.250500 ,27.250000,
	CRB, 242.500500, 244.999500 ,27.000000,
	BOO, 226.249500, 227.749500 ,26.000000,
	CRB, 227.749500, 242.500500 ,26.000000,
	LYR, 275.500500, 283.000500 ,26.000000,
	LMI, 161.250000, 165.000000 ,25.500000,
	LYR, 283.000500, 288.874500 ,25.500000,
	TRI, 25.000500, 28.750500 ,25.000000,
	PSC, 10.750500, 12.750000 ,23.750000,
	LMI, 157.500000, 161.250000 ,23.500000,
	VUL, 318.750000, 321.250500 ,23.500000,
	TAU, 85.500000, 88.249500 ,22.833300,
	AND, 1.000500, 2.125500 ,22.000000,
	SER, 238.750500, 240.499500 ,22.000000,
	GEM, 88.249500, 93.250500 ,21.500000,
	VUL, 297.499500, 303.750000 ,21.250000,
	VUL, 283.000500, 288.750000 ,21.083300,
	AND, 2.125500, 12.750000 ,21.000000,
	VUL, 303.750000, 308.500500 ,20.500000,
	GEM, 117.124500, 118.249500 ,20.000000,
	VUL, 308.500500, 318.750000 ,19.500000,
	VUL, 288.750000, 297.499500 ,19.166700,
	ARI, 49.249500, 50.500500 ,19.000000,
	SGE, 283.000500, 285.000000 ,18.500000,
	ORI, 85.500000, 86.500500 ,18.000000,
	GEM, 93.250500, 94.624500 ,17.500000,
	SGE, 285.000000, 297.499500 ,16.166700,
	TAU, 74.500500, 79.999500 ,16.000000,
	HER, 238.750500, 241.249500 ,16.000000,
	SGE, 297.499500, 303.750000 ,15.750000,
	TAU, 69.250500, 74.500500 ,15.500000,
	TAU, 79.999500, 84.000000 ,15.500000,
	COM, 192.499500, 202.500000 ,15.000000,
	HER, 258.750000, 273.750000 ,14.333300,
	COM, 178.000500, 192.499500 ,14.000000,
	GEM, 112.500000, 117.124500 ,13.500000,
	HER, 251.250000, 258.750000 ,12.833300,
	PEG, 0.000000, 2.125500 ,12.500000,
	TAU, 84.000000, 86.500500 ,12.500000,
	GEM, 105.000000, 112.500000 ,12.500000,
	PEG, 316.750500, 319.999500 ,12.500000,
	GEM, 94.624500, 103.999500 ,12.000000,
	HER, 273.750000, 283.000500 ,12.000000,
	DEL, 313.125000, 315.750000 ,11.833300,
	PEG, 315.750000, 316.750500 ,11.833300,
	LEO, 172.750500, 178.000500 ,11.000000,
	ORI, 93.625500, 94.624500 ,10.000000,
	GEM, 103.999500, 105.000000 ,10.000000,
	CNC, 117.124500, 118.875000 ,10.000000,
	PEG, 357.499500, 360.000000 ,10.000000,
	ARI, 25.000500, 49.249500 ,9.916700,
	DEL, 302.125500, 304.500000 ,8.500000,
	BOO, 202.500000, 226.249500 ,8.000000,
	PEG, 341.250000, 357.499500 ,7.500000,
	CNC, 118.875000, 138.750000 ,7.000000,
	LEO, 138.750000, 161.250000 ,7.000000,
	OPH, 273.750000, 279.933000 ,6.250000,
	AQL, 279.933000, 283.000500 ,6.250000,
	DEL, 312.499500, 313.125000 ,6.000000,
	CMI, 105.000000, 105.250500 ,5.500000,
	SER, 273.750000, 276.375000 ,4.500000,
	HER, 241.249500, 251.250000 ,4.000000,
	OPH, 273.750000, 276.375000 ,3.000000,
	PEG, 322.000500, 325.000500 ,2.750000,
	PSC, 0.000000, 30.000000 ,2.000000,
	SER, 278.749500, 283.000500 ,2.000000,
	DEL, 304.500000, 312.499500 ,2.000000,
	EQU, 312.499500, 319.999500 ,2.000000,
	PEG, 319.999500, 322.000500 ,2.000000,
	PEG, 330.000000, 341.250000 ,2.000000,
	PEG, 325.000500, 330.000000 ,1.750000,
	CMI, 105.250500, 108.000000 ,1.500000,
	TAU, 53.749500, 69.250500 ,0.000000,
	ORI, 69.250500, 70.000500 ,0.000000,
	CMI, 108.000000, 121.249500 ,0.000000,
	VIR, 220.000500, 226.249500 ,0.000000,
	OPH, 267.499500, 273.750000 ,0.000000,
	CET, 39.750000, 49.249500 ,-1.750000,
	TAU, 49.249500, 53.749500 ,-1.750000,
	SER, 226.249500, 244.000500 ,-3.250000,
	ORI, 70.000500, 76.249500 ,-4.000000,
	ORI, 87.499500, 93.625500 ,-4.000000,
	SER, 267.499500, 269.500500 ,-4.000000,
	SER, 273.750000, 278.749500 ,-4.000000,
	AQL, 278.749500, 283.000500 ,-4.000000,
	PSC, 341.250000, 357.499500 ,-4.000000,
	LEO, 161.250000, 172.750500 ,-6.000000,
	VIR, 172.750500, 177.499500 ,-6.000000,
	PSC, 0.000000, 4.999500 ,-7.000000,
	PSC, 357.499500, 360.000000 ,-7.000000,
	VIR, 213.750000, 220.000500 ,-8.000000,
	OPH, 238.750500, 244.000500 ,-8.000000,
	AQL, 300.000000, 307.999500 ,-9.000000,
	AQR, 319.999500, 328.000500 ,-9.000000,
	OPH, 257.500500, 269.500500 ,-10.000000,
	MON, 87.499500, 121.249500 ,-11.000000,
	ERI, 73.750500, 76.249500 ,-11.000000,
	ORI, 76.249500, 87.499500 ,-11.000000,
	HYA, 121.249500, 125.500500 ,-11.000000,
	SEX, 143.749500, 161.250000 ,-11.000000,
	VIR, 177.499500, 192.499500 ,-11.000000,
	OPH, 263.749500, 265.000500 ,-11.666700,
	AQL, 283.000500, 300.000000 ,-12.033300,
	ERI, 72.499500, 73.750500 ,-14.500000,
	AQR, 307.999500, 319.999500 ,-15.000000,
	SER, 257.500500, 273.750000 ,-16.000000,
	SCT, 273.750000, 283.000500 ,-16.000000,
	HYA, 125.500500, 128.749500 ,-17.000000,
	OPH, 244.000500, 245.625000 ,-18.250000,
	HYA, 128.749500, 136.249500 ,-19.000000,
	CRT, 161.250000, 162.499500 ,-19.000000,
	SCO, 244.000500, 245.625000 ,-19.250000,
	LIB, 235.000500, 238.750500 ,-20.000000,
	CRV, 188.749500, 192.499500 ,-22.000000,
	VIR, 192.499500, 213.750000 ,-22.000000,
	HYA, 136.249500, 146.250000 ,-24.000000,
	CET, 25.000500, 39.750000 ,-24.383300,
	ERI, 39.750000, 56.250000 ,-24.383300,
	CRT, 162.499500, 177.499500 ,-24.500000,
	CRV, 177.499500, 188.749500 ,-24.500000,
	LIB, 213.750000, 223.750500 ,-24.500000,
	OPH, 244.000500, 251.250000 ,-24.583300,
	CET, 0.000000, 25.000500 ,-25.500000,
	CAP, 319.999500, 328.000500 ,-25.500000,
	AQR, 328.000500, 357.499500 ,-25.500000,
	CET, 357.499500, 360.000000 ,-25.500000,
	HYA, 146.250000, 153.750000 ,-26.500000,
	ERI, 70.500000, 72.499500 ,-27.250000,
	LEP, 72.499500, 91.750500 ,-27.250000,
	CAP, 300.000000, 319.999500 ,-28.000000,
	HYA, 153.750000, 158.749500 ,-29.166700,
	HYA, 188.749500, 223.750500 ,-29.500000,
	LIB, 223.750500, 235.000500 ,-29.500000,
	SCO, 235.000500, 240.000000 ,-29.500000,
	ERI, 68.749500, 70.500000 ,-30.000000,
	OPH, 251.250000, 264.000000 ,-30.000000,
	SGR, 264.000000, 267.499500 ,-30.000000,
	HYA, 158.749500, 162.499500 ,-31.166700,
	CMA, 91.750500, 110.500500 ,-33.000000,
	HYA, 183.750000, 188.749500 ,-33.000000,
	HYA, 162.499500, 183.750000 ,-35.000000,
	FOR, 52.500000, 56.250000 ,-36.000000,
	PYX, 125.500500, 140.500500 ,-36.750000,
	ERI, 64.000500, 68.749500 ,-37.000000,
	SGR, 267.499500, 287.500500 ,-37.000000,
	PSA, 319.999500, 345.000000 ,-37.000000,
	SCL, 345.000000, 349.999500 ,-37.000000,
	FOR, 45.000000, 52.500000 ,-39.583300,
	ANT, 140.500500, 165.000000 ,-39.750000,
	SCL, 0.000000, 25.000500 ,-40.000000,
	FOR, 25.000500, 45.000000 ,-40.000000,
	ERI, 58.000500, 64.000500 ,-40.000000,
	SCL, 349.999500, 360.000000 ,-40.000000,
	CEN, 212.500500, 223.750500 ,-42.000000,
	LUP, 235.000500, 240.000000 ,-42.000000,
	SCO, 240.000000, 246.312000 ,-42.000000,
	CAE, 72.499500, 75.000000 ,-43.000000,
	COL, 75.000000, 98.749500 ,-43.000000,
	PUP, 120.000000, 125.500500 ,-43.000000,
	ERI, 51.250500, 58.000500 ,-44.000000,
	SCO, 246.312000, 267.499500 ,-45.500000,
	CRA, 267.499500, 287.500500 ,-45.500000,
	SGR, 287.500500, 304.999500 ,-45.500000,
	MIC, 304.999500, 319.999500 ,-45.500000,
	ERI, 45.000000, 51.250500 ,-46.000000,
	CAE, 67.500000, 72.499500 ,-46.500000,
	LUP, 229.999500, 235.000500 ,-48.000000,
	PHE, 0.000000, 34.999500 ,-48.166700,
	ERI, 40.000500, 45.000000 ,-49.000000,
	HOR, 61.249500, 64.000500 ,-49.000000,
	CAE, 64.000500, 67.500000 ,-49.000000,
	GRU, 319.999500, 330.000000 ,-50.000000,
	PUP, 90.000000, 120.000000 ,-50.750000,
	VEL, 120.000000, 122.500500 ,-50.750000,
	ERI, 36.250500, 40.000500 ,-51.000000,
	HOR, 57.499500, 61.249500 ,-51.000000,
	PHE, 0.000000, 27.499500 ,-51.500000,
	CAR, 90.000000, 92.500500 ,-52.500000,
	VEL, 122.500500, 126.750000 ,-53.000000,
	HOR, 52.500000, 57.499500 ,-53.166700,
	DOR, 57.499500, 60.000000 ,-53.166700,
	PHE, 0.000000, 23.749500 ,-53.500000,
	ERI, 32.500500, 36.250500 ,-54.000000,
	PIC, 67.500000, 75.000000 ,-54.000000,
	LUP, 225.750000, 229.999500 ,-54.000000,
	VEL, 126.750000, 132.499500 ,-54.500000,
	CAR, 92.500500, 97.500000 ,-55.000000,
	CEN, 177.499500, 192.499500 ,-55.000000,
	LUP, 212.500500, 225.750000 ,-55.000000,
	NOR, 225.750000, 229.999500 ,-55.000000,
	DOR, 60.000000, 64.999500 ,-56.500000,
	VEL, 132.499500, 165.000000 ,-56.500000,
	CEN, 165.000000, 168.750000 ,-56.500000,
	ARA, 262.500000, 270.000000 ,-57.000000,
	TEL, 270.000000, 304.999500 ,-57.000000,
	GRU, 330.000000, 349.999500 ,-57.000000,
	HOR, 48.000000, 52.500000 ,-57.500000,
	PIC, 75.000000, 82.500000 ,-57.500000,
	CAR, 97.500000, 102.499500 ,-58.000000,
	PHE, 0.000000, 19.999500 ,-58.500000,
	ERI, 19.999500, 32.500500 ,-58.500000,
	PHE, 349.999500, 360.000000 ,-58.500000,
	DOR, 64.999500, 68.749500 ,-59.000000,
	NOR, 229.999500, 246.312000 ,-60.000000,
	IND, 304.999500, 319.999500 ,-60.000000,
	PIC, 82.500000, 90.000000 ,-61.000000,
	CIR, 227.500500, 229.999500 ,-61.000000,
	ARA, 246.312000, 248.749500 ,-61.000000,
	CIR, 223.750500, 227.500500 ,-63.583300,
	ARA, 248.749500, 251.250000 ,-63.583300,
	PIC, 90.000000, 102.499500 ,-64.000000,
	CAR, 102.499500, 135.499500 ,-64.000000,
	CEN, 168.750000, 177.499500 ,-64.000000,
	CRU, 177.499500, 192.499500 ,-64.000000,
	CEN, 192.499500, 217.999500 ,-64.000000,
	CIR, 202.500000, 205.000500 ,-65.000000,
	ARA, 251.250000, 252.499500 ,-65.000000,
	HOR, 32.500500, 48.000000 ,-67.500000,
	RET, 48.000000, 68.749500 ,-67.500000,
	CIR, 221.250000, 223.750500 ,-67.500000,
	ARA, 252.499500, 262.500000 ,-67.500000,
	PAV, 262.500000, 270.000000 ,-67.500000,
	TUC, 330.000000, 349.999500 ,-67.500000,
	DOR, 68.749500, 98.749500 ,-70.000000,
	CIR, 205.000500, 221.250000 ,-70.000000,
	TRA, 221.250000, 255.000000 ,-70.000000,
	TUC, 0.000000, 19.999500 ,-75.000000,
	HYI, 52.500000, 68.749500 ,-75.000000,
	VOL, 98.749500, 135.499500 ,-75.000000,
	CAR, 135.499500, 168.750000 ,-75.000000,
	MUS, 168.750000, 205.000500 ,-75.000000,
	PAV, 270.000000, 319.999500 ,-75.000000,
	IND, 319.999500, 349.999500 ,-75.000000,
	TUC, 349.999500, 360.000000 ,-75.000000,
	TUC, 11.250000, 19.999500 ,-76.000000,
	HYI, 0.000000, 52.500000 ,-82.500000,
	CHA, 115.000500, 205.000500 ,-82.500000,
	APS, 205.000500, 270.000000 ,-82.500000,
	MEN, 52.500000, 115.000500 ,-85.000000,
	OCT, 0.000000, 360.000000 ,-90.000000
};

Constellation::Constellation()
{
}

Constellation::~Constellation()
{
}
	
const Glib::ustring& Constellation::get_constellation(double ra, double dec)
{
}

void Constellation::clip(double ra_min, double dec_min, double ra_max , double dec_max)
{
	m_min_ra = ra_min;
	if (m_min_ra < 0)
		m_min_ra = 0;
	
	m_max_ra = ra_max;
	if (m_max_ra > 360)
		m_max_ra = 360;
	
	m_min_dec = dec_min;
	if (m_min_dec < -90)
		m_min_dec = -90;
	
	m_max_dec = dec_max;
	if (m_max_dec > 90)
		m_max_dec = 90;
}

int Constellation::get_lines (std::vector<ConstLine>& lines)
{
	int count = 0;
	double sect_dec;
	double gradient;
	
	for (int i = 0; i < NUM_CONST_LINES; i++) {
		if (((const_lines[i].ra1 > m_min_ra) &&
			(const_lines[i].ra1 < m_max_ra) &&
			(const_lines[i].dec1 > m_min_dec) &&
			(const_lines[i].dec1 < m_max_dec)) ||
			((const_lines[i].ra2 > m_min_ra) &&
			(const_lines[i].ra2 < m_max_ra) &&
			(const_lines[i].dec2 > m_min_dec) &&
			(const_lines[i].dec2 < m_max_dec)))	{
				
				// check if ra lines cross 0h boundary
				if (const_lines[i].ra1 > 330 && const_lines[i].ra2 < 30) {
					
					// calculate intersections
					gradient = ((const_lines[i].ra2 + 360.0) - const_lines[i].ra1) / (const_lines[i].dec2 - const_lines[i].dec1);
					sect_dec = ((360.0 - const_lines[i].ra1) / gradient) + const_lines[i].dec1;			
					ConstLine line1, line2;
					
					line1.ra1 = const_lines[i].ra1;
					line1.dec1 = const_lines[i].dec1;
					line1.ra2 = 360.0;
					line1.dec2 = sect_dec;
					line2.ra1 = 0.0;
					line2.dec1 = sect_dec;
					line2.ra2 = const_lines[i].ra2;
					line2.dec2 = const_lines[i].dec2;
					
					lines.push_back(line1);
					lines.push_back(line2);
					count += 2;
				} else if (const_lines[i].ra1 < 30 && const_lines[i].ra2 > 330) {			
					
					// calculate intersections
					gradient = (const_lines[i].ra1 - (const_lines[i].ra2 - 360.0)) / (const_lines[i].dec1 - const_lines[i].dec2);
					sect_dec = (const_lines[i].ra1 / gradient) + const_lines[i].dec2;		
					ConstLine line1, line2;
					
					line1.ra1 = const_lines[i].ra1;
					line1.dec1 = const_lines[i].dec1;
					line1.ra2 = 0.;
					line1.dec2 = sect_dec;
					line2.ra1 = 360.0;
					line2.dec1 = sect_dec;
					line2.ra2 = const_lines[i].ra2;
					line2.dec2 = const_lines[i].dec2;
					
					lines.push_back(line1);
					lines.push_back(line2);
					count +=2;
				} else {
					lines.push_back(const_lines[i]);
					count++;
				}
			}
		}
	return count;
}

int Constellation::get_names (std::vector<ConstName>& names)
{
	int count = 0;
	
	return count;
}

int Constellation::get_bounds (std::vector<ConstBound>& boundaries)
{
	int count = 0;
	
	return count;
}

}
