// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright Liam Girdwood 2003

#ifndef _SKY_APPBAR_HH
#define _SKY_APPBAR_HH

#include "astro_object.hh"

#include <gtkmm/label.h>
#include <gtkmm/box.h>
#include <gtkmm/separator.h>

/*! \namespace Vega
* \brief Nova Virtual Sky Engine
*/
namespace Vega
{

/*! \class SkyProj
* Sky projection base class.
*
* All Virtual sky projections are derived from this class.
*/
class SkyAppbar : public Gtk::HBox
{
	public:
		SkyAppbar();
		~SkyAppbar();

	private:
		
		// equ posn
		Gtk::HBox m_equ_bar;
		Gtk::HBox m_equ_ra_bar;
		Gtk::HBox m_equ_dec_bar;
		Gtk::Label m_equ_rah;
		Gtk::Label m_equ_ram;
		Gtk::Label m_equ_ras;
		Gtk::Label m_equ_ded;
		Gtk::Label m_equ_dem;
		Gtk::Label m_equ_des;
		Gtk::Label m_equ_sep1;
		Gtk::Label m_equ_sep2;
		Gtk::Label m_equ_title;
		Gtk::Label m_equ_ra_sep1;
		Gtk::Label m_equ_ra_sep2;
		Gtk::Label m_equ_dec_sep1;
		Gtk::Label m_equ_dec_sep2;
	
		// hrz posn
		Gtk::HBox m_hrz_bar;
		Gtk::HBox m_hrz_alt_bar;
		Gtk::HBox m_hrz_az_bar;
		Gtk::Label m_hrz_ald;
		Gtk::Label m_hrz_alm;
		Gtk::Label m_hrz_als;
		Gtk::Label m_hrz_azd;
		Gtk::Label m_hrz_azm;
		Gtk::Label m_hrz_azs;
		Gtk::Label m_hrz_sep1;
		Gtk::Label m_hrz_sep2;
		Gtk::Label m_hrz_title;
		Gtk::Label m_hrz_alt_sep1;
		Gtk::Label m_hrz_alt_sep2;
		Gtk::Label m_hrz_az_sep1;
		Gtk::Label m_hrz_az_sep2;
	
		// object label
		Gtk::HBox m_object_bar;
		Gtk::Label m_object_name;
		Gtk::Label m_object_mag;
		Gtk::Label m_object_title;
		Gtk::Label m_object_mag_title;
		
		// FOV
		Gtk::HBox m_fov_bar;
		Gtk::Label m_fov;
		Gtk::Label m_fov_title;
		
		// separators
		Gtk::VSeparator m_sep1, m_sep2, m_sep3, m_sep4;
		
	public:
		
		void set_equ_posn(double ra, double dec);
		void set_hrz_posn(double alt, double az);
		void set_object(Castor::AstroObject* object);
		void set_fov(double fov);
};

};

#endif
