// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright Liam Girdwood 2003

#ifndef _SKY_FLAT_HH
#define _SKY_FLAT_HH

#include "sky_proj.hh"

/*! \namespace Vega
* \brief Nova Virtual Sky Engine
*/
namespace Vega
{

/*! \class SkyFlat
* Represents a flat sky projection.
*/
class SkyFlat : public SkyProj
{
	public:
		SkyFlat();
		~SkyFlat();
	
		void render_grid();
		void render_const_lines();
		void render_const_bounds();
		void render_const_names();
		void render_planets();
	
		/*! \fn void get_position (double x, double y, double& ra, double& dec) = 0;
		* \brief get sky ra,dec at x,y coordinates
		*/
		void get_position (double x, double y, double& ra, double& dec);
	
		/*! \fn render_basic()
		* Render the basic/compulsary sky objects
		*/
		void render_basic();
	
		/*! \fn bool is_visible(double x, double y);
		* Is the object visible ?
		*/
		bool is_visible(double x, double y);
		
	private:
		void transform(double& x, double& y, double ra_offset);
};

};

#endif
